#! /usr/bin/python3
# this program can be used as a special editor. Example:
# EDITOR=$(pwd)/confiller.py crontab -u dummy -e
# this file is a dependency of the test check_significant_header

import sys
import os
import time

# get the data from the crontab
with open(sys.argv[1]) as infile:
    lines = infile.read()
    
# add a new line (or some more, if LINES is defined in the environment)
# to the crontab

otherlines = os.environ.get("LINES")
if otherlines:
    if otherlines[-1] != '\n':
        otherlines += '\n'
    lines += otherlines
else:
    # by default, add at least one line
    lines += "* * * * * /bin/ls\n"

# wait just a short time to ensure that the crontab file will be
# correctly managed.
time.sleep(1)
with open(sys.argv[1], "w") as outfile:
    outfile.write(lines)



#! /usr/bin/python3
# checks that the data coming from stdin are prefixed with the
# standard header for crontabs found in Debian
# this file is a dependency of the test check_significant_header

import sys

crontab_contents = sys.stdin.read()
assert(crontab_contents.startswith("""\
# Edit this file to introduce tasks to be run by cron.
# 
# Each task to run has to be defined through a single line
# indicating with different fields when the task will be run
# and what command to run for the task
# 
# To define the time you can provide concrete values for
# minute (m), hour (h), day of month (dom), month (mon),
# and day of week (dow) or use '*' in these fields (for 'any').
# 
# Notice that tasks will be started based on the cron's system
# daemon's notion of time and timezones.
# 
# Output of the crontab jobs (including errors) is sent through
# email to the user the crontab file belongs to (unless redirected).
# 
# For example, you can run a backup of all your user accounts
# at 5 a.m every week with:
# 0 5 * * 1 tar -zcf /var/backups/home.tgz /home/
# 
# For more information see the manual pages of crontab(5) and cron(8)
# 
# m h  dom mon dow   command
"""))
print("======== The header reported by crontab -l is correct ======")

